exception — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# exception

Functions and widget to represent exceptions to the user

class `camelot.view.controls.exception.` `ExceptionDialog`(exception_info)

  Dialog to display an exception to the user

`camelot.view.controls.exception.` `model_thread_exception_message_box`(exception_info)

  Display an exception that occurred in the model thread in a message box, use this function as the exception argument in the model thread’s post function to represent the exception to the user

  Parameters: | exception_info – a tuple containing exception information

`camelot.view.controls.exception.` `register_exception`(logger, text, exception)

  Log an exception and return a serialized form of the exception with exception information in a user readable format, to be used when displaying an exception message box.

  that serialized form can be fed to the model_thread_exception_message_box function.

  Returns: | a tuple with exception information

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus